@@ -62,8 +62,8 @@ class Seti():
         return b64encode(cipher_rsa.sign(hash)).decode("utf-8")
     
     def send_request(self,data:dict,sign_data:str,path:str):
-        url = self.seti_path
-        r = requests.post(url=url+path, json=data,headers={
+        url = self.seti_path+path
+        r = requests.post(url=url, json=data,headers={
             "authorization":self.api_key,
             "sign": sign_data
         })
@@ -136,6 +136,24 @@ class Seti():
         encode_data = self.sign_data(data_validate_wallet)
         return BasicResponse(self.send_request(data_validate_wallet,encode_data,VALIDATE_WALLET_URL))
     
+    def read_wallet_data(self,secret:str):
+        self.is_error = False
+        data_read_wallet = {
+            "secret": secret,
+         }
+        READ_WALLET_URL = "read-wallet"
+        encode_data = self.sign_data(data_read_wallet)
+        return ResponseCreateTransaction(self.send_request(data_read_wallet,encode_data,READ_WALLET_URL))
+    
+    def read_wallet_transactions(self,secret:str):
+        self.is_error = False
+        data_read_wallet_transactions = {
+            "secret": secret,
+         }
+        READ_WALLET_TRANSACTIONS_URL = "read-wallet-transactions"
+        encode_data = self.sign_data(data_read_wallet_transactions)
+        return ResponseCreateTransaction(self.send_request(data_read_wallet_transactions,encode_data,READ_WALLET_TRANSACTIONS_URL))
+    
     def send_money_between_wallets(self,from_secret:str,to_secret:str,value:int):
         self.is_error = False
         self.validate_value(value)
@@ -148,7 +166,6 @@ class Seti():
         encode_data = self.sign_data(data_send_money)
         return ResponseCreateTransaction(self.send_request(data_send_money,encode_data,SEND_MONEY_WALLETS_URL))
     
-    
     def retention_money(self,from_secret:str,value:int):
         self.is_error =False
         data_retention_money = {
